@@ -1575,8 +1575,7 @@ generic_packetizer_c *
 ogm_v_vp8_demuxer_c::create_packetizer() {
   auto ptzr_obj = new vpx_video_packetizer_c(reader, m_ti, codec_c::type_e::V_VP8);
 
-  ptzr_obj->set_video_pixel_width(pixel_width);
-  ptzr_obj->set_video_pixel_height(pixel_height);
+  ptzr_obj->set_video_pixel_dimensions(pixel_width, pixel_height);
   ptzr_obj->set_video_display_dimensions(display_width, display_height, generic_packetizer_c::ddu_pixels, OPTION_SOURCE_BITSTREAM);
   ptzr_obj->set_track_default_duration(default_duration);
 
