@@ -14,6 +14,7 @@ class BoolValuePage: public ValuePage {
 public:
   QComboBox *m_cbValue{};
   uint64_t m_originalValue{};
+  bool m_valueIfNotPresent{};
 
 public:
   BoolValuePage(Tab &parent, PageBase &topLevelPage, EbmlMaster &master, EbmlCallbacks const &callbacks, translatable_string_c const &title, translatable_string_c const &description);
@@ -22,6 +23,7 @@ public:
   virtual QWidget *createInputControl() override;
   virtual QString originalValueAsString() const override;
   virtual QString currentValueAsString() const override;
+  virtual bool currentValue(bool valueIfNotPresent) const;
   virtual void resetValue() override;
   virtual bool validateValue() const override;
   virtual void copyValueToElement() override;
