@@ -31,7 +31,9 @@ LanguageValuePage::~LanguageValuePage() {
 QWidget *
 LanguageValuePage::createInputControl() {
   m_originalValue   = m_element ? static_cast<EbmlString *>(m_element)->GetValue() : "eng";
-  auto languageOpt  = mtx::iso639::look_up(m_originalValue, true);
+  auto qOriginal    = Q(m_originalValue);
+  auto languageOnly = qOriginal.mid(0, qOriginal.indexOf(Q('-')));
+  auto languageOpt  = mtx::iso639::look_up(to_utf8(languageOnly), true);
   auto currentValue = languageOpt ? languageOpt->alpha_3_code : m_originalValue;
 
   m_cbValue = new Util::LanguageComboBox{this};
@@ -60,6 +62,15 @@ LanguageValuePage::currentValueAsString()
   return m_cbValue->currentData().toString();
 }
 
+mtx::bcp47::language_c
+LanguageValuePage::currentValue(mtx::bcp47::language_c const &valueIfNotPresent)
+  const {
+  if (!m_present && !m_cbAddOrRemove->isChecked())
+    return valueIfNotPresent;
+
+  return mtx::bcp47::language_c::parse(to_utf8(m_cbValue->currentData().toString()));
+}
+
 void
 LanguageValuePage::resetValue() {
   m_cbValue->setCurrentByData(Q(m_originalValue));
