@@ -415,11 +415,15 @@ Tab::populateTree() {
     handleSegmentInfo(data);
   });
 
-    m_analyzer->with_elements(EBML_ID(KaxTracks), [this](kax_analyzer_data_c const &data) {
+  m_analyzer->with_elements(EBML_ID(KaxTracks), [this](kax_analyzer_data_c const &data) {
     handleTracks(data);
   });
 
   handleAttachments();
+
+  for (auto const &page : m_model->topLevelPages())
+    if (dynamic_cast<TrackTypePage *>(page))
+      static_cast<TrackTypePage *>(page)->updateModelItems();
 }
 
 void
@@ -433,6 +437,8 @@ Tab::selectionChanged(QModelIndex const &current,
   auto selectedPage = m_model->selectedPage(current);
   if (selectedPage)
     ui->pageContainer->setCurrentWidget(selectedPage);
+
+  MainWindow::get()->headerEditorTool()->enableMenuActions();
 }
 
 bool
@@ -563,8 +569,11 @@ Tab::createValuePage(TopLevelPage &parentPage,
        : type                == property_element_c::EBMLT_DATE    ? new TimeValuePage{           *this, parentPage, parentMaster, *element.m_callbacks, element.m_title, element.m_description}
        :                                                            static_cast<ValuePage *>(nullptr);
 
-  if (page)
+  if (page) {
     page->init();
+    if (dynamic_cast<TrackTypePage *>(&parentPage))
+      connect(page, &ValuePage::valueChanged, static_cast<TrackTypePage *>(&parentPage), &TrackTypePage::updateModelItems);
+  }
 
   return page;
 }
@@ -656,6 +665,8 @@ Tab::handleTracks(kax_analyzer_data_c const &data) {
       if (parentPage && parentMaster)
         createValuePage(*parentPage, *parentMaster, propElement);
     }
+
+    page->deriveLanguageIETFFromLegacyIfNotPresent();
   }
 }
 
@@ -977,6 +988,8 @@ Tab::walkPagesOfSelectedTopLevelNode(std::function<bool(PageBase *)> worker) {
   if (!topLevelIdx.isValid())
     return;
 
+  topLevelIdx = topLevelIdx.sibling(topLevelIdx.row(), 0);
+
   while (topLevelIdx.parent().isValid())
     topLevelIdx = topLevelIdx.parent();
 
@@ -1007,6 +1020,8 @@ Tab::toggleSpecificTrackFlag(unsigned int wantedId) {
 
     return true;
   });
+
+  updateSelectedTopLevelPageModelItems();
 }
 
 void
@@ -1045,8 +1060,10 @@ Tab::changeTrackLanguage(QString const &formattedLanguage,
     return !languageFound || !languageIETFFound;
   });
 
-  if (trackName.isEmpty())
+  if (trackName.isEmpty()) {
+    updateSelectedTopLevelPageModelItems();
     return;
+  }
 
   walkPagesOfSelectedTopLevelNode([&trackName](auto *pageBase) -> bool {
     auto trackNamePage = dynamic_cast<TrackNamePage *>(pageBase);
@@ -1058,6 +1075,8 @@ Tab::changeTrackLanguage(QString const &formattedLanguage,
 
     return false;
   });
+
+  updateSelectedTopLevelPageModelItems();
 }
 
 void
@@ -1096,4 +1115,19 @@ Tab::moveElementUpOrDown(bool up) {
     focus->setFocus();
 }
 
+void
+Tab::updateSelectedTopLevelPageModelItems() {
+  auto topLevelIdx = ui->elements->selectionModel()->currentIndex();
+
+  if (!topLevelIdx.isValid())
+    return;
+
+  while (topLevelIdx.parent().isValid())
+    topLevelIdx = topLevelIdx.parent();
+
+  auto page = m_model->selectedPage(topLevelIdx);
+  if (dynamic_cast<TrackTypePage *>(page))
+    static_cast<TrackTypePage *>(page)->updateModelItems();
+}
+
 }
