@@ -27,12 +27,11 @@
 using namespace libmatroska;
 
 vc1_video_packetizer_c::vc1_video_packetizer_c(generic_reader_c *n_reader, track_info_c &n_ti)
-  : generic_packetizer_c(n_reader, n_ti)
+  : generic_packetizer_c{n_reader, n_ti, track_video}
   , m_previous_timestamp(-1)
 {
   m_relaxed_timestamp_checking = true;
 
-  set_track_type(track_video);
   set_codec_id(MKV_V_MSCOMP);
 
   // Dummy values
@@ -58,8 +57,7 @@ vc1_video_packetizer_c::set_headers() {
   put_uint32_le(&bih->bi_x_pels_per_meter, 1);
   put_uint32_le(&bih->bi_y_pels_per_meter, 1);
 
-  set_video_pixel_width(m_seqhdr.pixel_width);
-  set_video_pixel_height(m_seqhdr.pixel_height);
+  set_video_pixel_dimensions(m_seqhdr.pixel_width, m_seqhdr.pixel_height);
 
   if (m_raw_headers) {
     if (m_seqhdr.display_info_flag) {
